@@ -5,10 +5,10 @@ generatelens <- function(maxLen, minLen, stdevLen, nString, distLen){
     len <- round(x = len)
   }
   else if(distLen == 'uniform'){
-    len <- sample(minLen:maxLen, nString)
+    len <- sample(minLen:maxLen, nString, replace = TRUE)
   }
   else{
     len <- "err in generatelens"
   }
   len
-}
\ No newline at end of file
+}
